@@ -12,8 +12,8 @@
 
 #include "settings.h"
 
-#include <KMessageBox>
 #include <KLocalizedString>
+#include <KMessageBox>
 #include <kwallet.h>
 
 DlgWebinterface::DlgWebinterface(QDialog *parent)
@@ -22,9 +22,9 @@ DlgWebinterface::DlgWebinterface(QDialog *parent)
     setupUi(this);
 
     readConfig();
-    
+
     connect(parent, &QDialog::accepted, this, &DlgWebinterface::saveSettings);
-    connect(webinterfacePwd, &KLineEdit::textChanged, this, &DlgWebinterface::changed);
+    connect(webinterfacePwd, &KPasswordLineEdit::passwordChanged, this, &DlgWebinterface::changed);
 }
 
 DlgWebinterface::~DlgWebinterface()
@@ -36,7 +36,7 @@ void DlgWebinterface::readConfig()
 {
     if (Settings::webinterfaceEnabled()) {
         m_wallet = KWallet::Wallet::openWallet(KWallet::Wallet::LocalWallet(),
-                                               winId(),///Use MainWindow?
+                                               winId(), /// Use MainWindow?
                                                KWallet::Wallet::Asynchronous);
         if (m_wallet) {
             connect(m_wallet, &KWallet::Wallet::walletOpened, this, &DlgWebinterface::walletOpened);
@@ -48,13 +48,10 @@ void DlgWebinterface::readConfig()
 
 void DlgWebinterface::walletOpened(bool opened)
 {
-    if (opened &&
-        (m_wallet->hasFolder("KGet") ||
-         m_wallet->createFolder("KGet")) &&
-         m_wallet->setFolder("KGet")) {
+    if (opened && (m_wallet->hasFolder("KGet") || m_wallet->createFolder("KGet")) && m_wallet->setFolder("KGet")) {
         QString pwd;
         m_wallet->readPassword("Webinterface", pwd);
-        webinterfacePwd->setText(pwd);
+        webinterfacePwd->setPassword(pwd);
     } else {
         KMessageBox::error(nullptr, i18n("Could not open KWallet"));
     }
@@ -63,9 +60,7 @@ void DlgWebinterface::walletOpened(bool opened)
 void DlgWebinterface::saveSettings()
 {
     if (m_wallet) {
-        m_wallet->writePassword("Webinterface", webinterfacePwd->text());
+        m_wallet->writePassword("Webinterface", webinterfacePwd->password());
     }
     Q_EMIT saved();
 }
-
-
