@@ -1,31 +1,31 @@
 /**************************************************************************
-*   Copyright (C) 2009-2011 Matthias Fuchs <mat69@gmx.net>                *
-*                                                                         *
-*   This program is free software; you can redistribute it and/or modify  *
-*   it under the terms of the GNU General Public License as published by  *
-*   the Free Software Foundation; either version 2 of the License, or     *
-*   (at your option) any later version.                                   *
-*                                                                         *
-*   This program is distributed in the hope that it will be useful,       *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
-*   GNU General Public License for more details.                          *
-*                                                                         *
-*   You should have received a copy of the GNU General Public License     *
-*   along with this program; if not, write to the                         *
-*   Free Software Foundation, Inc.,                                       *
-*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
-***************************************************************************/
+ *   Copyright (C) 2009-2011 Matthias Fuchs <mat69@gmx.net>                *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
+ ***************************************************************************/
 
 #include "keydownloader.h"
 #include "settings.h"
 #include "signature_p.h"
 
 #include "kget_debug.h"
-#include <QDebug>
 #include <KIO/Job>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <QDebug>
 
 #ifdef HAVE_QGPGME
 #include <gpgme++/context.h>
@@ -35,7 +35,7 @@
 #endif
 
 KeyDownloader::KeyDownloader(QObject *parent)
-  : QObject(parent)
+    : QObject(parent)
 {
 }
 
@@ -43,9 +43,9 @@ bool KeyDownloader::isValid() const
 {
 #ifdef HAVE_QGPGME
     return true;
-#else //HAVE_QGPGME
+#else // HAVE_QGPGME
     return false;
-#endif //HAVE_QGPGME
+#endif // HAVE_QGPGME
 }
 
 void KeyDownloader::downloadKey(QString fingerprint, Signature *sig)
@@ -70,9 +70,7 @@ void KeyDownloader::downloadKey(QString fingerprint, Signature *sig, bool mirror
     } else {
         const QStringList servers = Settings::signatureKeyServers();
         if (!servers.count()) {
-            KMessageBox::error(nullptr,
-                               i18n("No server for downloading keys is specified in settings. Downloading aborted."),
-                               i18n("No key server"));
+            KMessageBox::error(nullptr, i18n("No server for downloading keys is specified in settings. Downloading aborted."), i18n("No key server"));
             return;
         }
 
@@ -86,14 +84,14 @@ void KeyDownloader::downloadKey(QString fingerprint, Signature *sig, bool mirror
                 }
             }
         } else {
-             mirror = servers.first();
+            mirror = servers.first();
         }
 
         if (mirror.isEmpty()) {
             KMessageBox::error(nullptr,
                                i18n("No useful key server found, key not downloaded. Add more servers to the settings or restart KGet and retry downloading."),
                                i18n("No key server"));
-           return;
+            return;
         }
 
         m_triedMirrors.insert(fingerprint, mirror);
@@ -122,7 +120,7 @@ void KeyDownloader::slotDownloaded(KJob *job)
     }
 
     const QString fingerprint = m_jobs[job];
-    auto *transferJob = static_cast<KIO::StoredTransferJob*>(job);
+    auto *transferJob = static_cast<KIO::StoredTransferJob *>(job);
 
     if (transferJob->isErrorPage()) {
         qCDebug(KGET_DEBUG) << "Mirror did not work, try another one.";
@@ -130,7 +128,6 @@ void KeyDownloader::slotDownloaded(KJob *job)
         return;
     }
 
-
     QByteArray data = transferJob->data();
     if (data.isEmpty()) {
         qCDebug(KGET_DEBUG) << "Downloaded data is empty.";
@@ -166,21 +163,20 @@ void KeyDownloader::slotDownloaded(KJob *job)
     GpgME::ImportResult importResult = context->importKeys(key);
     err = importResult.error();
     if (err) {
-        qCDebug(KGET_DEBUG) << "Error while importing key.";;
+        qCDebug(KGET_DEBUG) << "Error while importing key.";
+        ;
         return;
     }
 
     qCDebug(KGET_DEBUG) << "Key downloaded, notifying requesters.";
 
-    QList<Signature*> sigs = m_downloading.values(fingerprint);
+    QList<Signature *> sigs = m_downloading.values(fingerprint);
     foreach (Signature *sig, sigs) {
         sig->d->signatureDownloaded();
     }
     m_downloading.remove(fingerprint);
-#else //HAVE_QGPGME
+#else // HAVE_QGPGME
     Q_UNUSED(job)
     qCWarning(KGET_DEBUG) << "No QGPGME support.";
-#endif //HAVE_QGPGME
+#endif // HAVE_QGPGME
 }
-
-
