@@ -19,19 +19,16 @@
 
 #include "mmstransfer.h"
 
-
 #include "kget_debug.h"
 #include <QDebug>
 #include <QDir>
 #include <QStandardPaths>
 
-MmsTransfer::MmsTransfer(TransferGroup * parent, TransferFactory * factory,
-                        Scheduler * scheduler, const QUrl & source, const
-                        QUrl &dest, const QDomElement * e)
-    : Transfer(parent, factory, scheduler, source, dest, e),
-    m_mmsdownload(NULL),
-    m_amountThreads(MmsSettings::threads()),
-    m_retryDownload(false)
+MmsTransfer::MmsTransfer(TransferGroup *parent, TransferFactory *factory, Scheduler *scheduler, const QUrl &source, const QUrl &dest, const QDomElement *e)
+    : Transfer(parent, factory, scheduler, source, dest, e)
+    , m_mmsdownload(NULL)
+    , m_amountThreads(MmsSettings::threads())
+    , m_retryDownload(false)
 {
     // make sure that the DataLocation directory exists (earlier this used to be handled by KStandardDirs)
     if (!QFileInfo::exists(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation))) {
@@ -58,20 +55,14 @@ void MmsTransfer::start()
     }
 
     setStatus(Job::Running, i18nc("transfer state: running", "Running...."), "media-playback-start");
-    m_mmsdownload = new MmsDownload(m_source.toString(), m_dest.toLocalFile(),
-                                    m_fileTemp, m_amountThreads);
+    m_mmsdownload = new MmsDownload(m_source.toString(), m_dest.toLocalFile(), m_fileTemp, m_amountThreads);
     connect(m_mmsdownload, SIGNAL(finished()), this, SLOT(slotResult()));
     connect(m_mmsdownload, SIGNAL(signBrokenUrl()), this, SLOT(slotBrokenUrl()));
-    connect(m_mmsdownload, SIGNAL(signNotAllowMultiDownload()), this,
-            SLOT(slotNotAllowMultiDownload()));
-    connect(m_mmsdownload, SIGNAL(signTotalSize(qulonglong)), this,
-            SLOT(slotTotalSize(qulonglong)));
-    connect(m_mmsdownload, SIGNAL(signDownloaded(qulonglong)), this,
-            SLOT(slotProcessedSizeAndPercent(qulonglong)));
-    connect(m_mmsdownload, SIGNAL(signSpeed(ulong)), this,
-            SLOT(slotSpeed(ulong)));
-    connect(m_mmsdownload, SIGNAL(signRestartDownload(int)), this,
-            SLOT(slotConnectionsErrors(int)));
+    connect(m_mmsdownload, SIGNAL(signNotAllowMultiDownload()), this, SLOT(slotNotAllowMultiDownload()));
+    connect(m_mmsdownload, SIGNAL(signTotalSize(qulonglong)), this, SLOT(slotTotalSize(qulonglong)));
+    connect(m_mmsdownload, SIGNAL(signDownloaded(qulonglong)), this, SLOT(slotProcessedSizeAndPercent(qulonglong)));
+    connect(m_mmsdownload, SIGNAL(signSpeed(ulong)), this, SLOT(slotSpeed(ulong)));
+    connect(m_mmsdownload, SIGNAL(signRestartDownload(int)), this, SLOT(slotConnectionsErrors(int)));
     m_mmsdownload->start();
     setTransferChange(Tc_Status, true);
 }
@@ -84,7 +75,7 @@ void MmsTransfer::stop()
     if ((status() == Stopped) || (status() == Finished)) {
         return;
     }
-    
+
     if (m_mmsdownload) {
         if (m_mmsdownload->threadsAlive() > 0) {
             m_mmsdownload->stopTransfer();
@@ -112,17 +103,17 @@ void MmsTransfer::deinit(Transfer::DeleteOptions options)
 }
 
 void MmsTransfer::slotResult()
-{   
+{
     /** This slot is connected with the signal finish of m_mmsdownload*/
     /** Deleting m_mmsdownload.*/
     m_mmsdownload->deleteLater();
     m_mmsdownload = NULL;
-    
+
     /** If the download end without problems is changed the status to Finished and is deleted
-     * the temporary file where is saved the status of all threads that download the file.     
+     * the temporary file where is saved the status of all threads that download the file.
      */
     if (m_downloadedSize == m_totalSize && m_totalSize != 0) {
-        setStatus(Job::Finished, i18nc("Transfer State:Finished","Finished"), "dialog-ok");
+        setStatus(Job::Finished, i18nc("Transfer State:Finished", "Finished"), "dialog-ok");
         m_percent = 100;
         m_downloadSpeed = 0;
         setTransferChange(Tc_Status | Tc_Percent | Tc_DownloadSpeed, true);
@@ -131,9 +122,9 @@ void MmsTransfer::slotResult()
             qCDebug(KGET_DEBUG) << "Could not delete " << m_fileTemp;
         }
     }
-     
+
     /** If m_retryDownload == true then some threads has fail to connect, so the download was
-     * stopped in MmsTransfer::slotConnectionsErrors() and here when all the connected thread 
+     * stopped in MmsTransfer::slotConnectionsErrors() and here when all the connected thread
      * are finished we delete the temporary file and we start again the download using the amount
      * of threads defined in MmsTransfer::slotConnectionsErrors().
      */
@@ -156,7 +147,7 @@ void MmsTransfer::slotTotalSize(qulonglong size)
 void MmsTransfer::slotSpeed(ulong speed)
 {
     m_downloadSpeed = (status() == Running) ? speed : 0;
-    setTransferChange(Tc_DownloadSpeed, true); 
+    setTransferChange(Tc_DownloadSpeed, true);
 }
 
 void MmsTransfer::slotProcessedSizeAndPercent(qulonglong size)
@@ -168,24 +159,25 @@ void MmsTransfer::slotProcessedSizeAndPercent(qulonglong size)
 
 void MmsTransfer::slotBrokenUrl()
 {
-    setError(i18n("Download failed, could not access this URL."), "dialog-cancel",
-            Job::NotSolveable);
+    setError(i18n("Download failed, could not access this URL."), "dialog-cancel", Job::NotSolveable);
     setTransferChange(Tc_Status, true);
 }
 
 void MmsTransfer::slotNotAllowMultiDownload()
 {
-    /** Some stream not allow seek in to a position, so we can't use more than one thread to 
+    /** Some stream not allow seek in to a position, so we can't use more than one thread to
      * download the file, this is notify to the user because the download will take longer.
      */
-    KGet::showNotification(nullptr, "notification", i18n("This URL does not allow multiple connections,\n"
+    KGet::showNotification(nullptr,
+                           "notification",
+                           i18n("This URL does not allow multiple connections,\n"
                                 "the download will take longer."));
 }
 
 void MmsTransfer::slotConnectionsErrors(int connections)
 {
     /** Here is called stop() for stop the download, set a new amount of thread
-     * and set m_retryDownload = true for restart the download when mmsdownload is finish and 
+     * and set m_retryDownload = true for restart the download when mmsdownload is finish and
      * Q_EMIT a signal connected with MmsTransfer::slotResult(), see in MmsTransfer::slotResult()
      * for understand when its started again the download.
      */
@@ -197,5 +189,3 @@ void MmsTransfer::slotConnectionsErrors(int connections)
         m_amountThreads--;
     }
 }
-
-
